Notifications Python Module
=============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   notify.config
   notify.globals
   notify.orm
   notify.rest
   notify.jsonpath
   notify.tasks
   notify.wsgi

.. automodule:: pacifica.notifications
   :members:
   :private-members:
   :special-members:
